Type: Package
Package: EpiCompare
Title: Comparison, Benchmarking & QC of Epigenomic Datasets
Version: 1.14.0
Authors@R: c(
    person(given = "Sera", family = "Choi", 
        email = "serachoi1230@gmail.com", 
        role = "aut",
        comment = c(ORCID = "0000-0002-5077-1984")),
    person(given="Brian", family="Schilder", 
        email = "brian_schilder@alumni.brown.edu", 
        role = "aut",
        comment = c(ORCID = "0000-0001-5949-2191")),
     person(given="Leyla", family="Abbasova", 
        email = "profernitsky@gmail.com", 
        role = "aut"), 
    person(given="Alan", family="Murphy", 
        email = "alanmurph94@hotmail.com", 
        role = "aut",
        comment = c(ORCID = "0000-0002-2487-8753")),
    person(given="Nathan", family="Skene", 
        email = "nathan.skene@gmail.com", 
        role = "aut",
        comment = c(ORCID = "0000-0002-6807-3180")),
    person(given="Thomas", family="Roberts",
        email = "tomroberts.work15@gmail.com",
        role = "ctb"),
    person(given="Hiranyamaya", family="Dash", 
        email = "hdash.work@gmail.com",
        role = "cre",
        comment = c(ORCID = "0009-0005-5514-505X"))
  )
Description: EpiCompare is used to compare and analyse epigenetic datasets 
  for quality control and benchmarking purposes. 
  The package outputs an HTML report consisting of three sections: 
  (1. General metrics) Metrics on peaks (percentage of blacklisted and 
  non-standard peaks, and peak widths) and fragments (duplication rate) 
  of samples, 
  (2. Peak overlap) Percentage and statistical significance of 
  overlapping and non-overlapping peaks. Also includes upset plot and 
  (3. Functional annotation) functional annotation 
  (ChromHMM, ChIPseeker and enrichment analysis) of peaks. 
  Also includes peak enrichment around TSS.
License: GPL-3
URL: https://github.com/neurogenomics/EpiCompare
BugReports: https://github.com/neurogenomics/EpiCompare/issues
Depends: R (>= 4.2.0)
Imports: AnnotationHub, ChIPseeker, data.table, genomation,
        GenomicRanges, IRanges (>= 2.41.3), Seqinfo (>= 0.99.2),
        GenomeInfoDb (>= 1.45.7), ggplot2 (>= 3.5.0), htmltools,
        methods, plotly, reshape2, rmarkdown, rtracklayer, stats,
        stringr, utils, BiocGenerics, downloadthis, parallel
Suggests: rworkflows, BiocFileCache, BiocParallel, BiocStyle,
        clusterProfiler, GenomicAlignments, grDevices, knitr,
        org.Hs.eg.db, testthat (>= 3.0.0), tidyr,
        TxDb.Hsapiens.UCSC.hg19.knownGene,
        TxDb.Hsapiens.UCSC.hg38.knownGene,
        TxDb.Mmusculus.UCSC.mm9.knownGene,
        TxDb.Mmusculus.UCSC.mm10.knownGene,
        BSgenome.Hsapiens.UCSC.hg19, BSgenome.Hsapiens.UCSC.hg38,
        BSgenome.Mmusculus.UCSC.mm9, BSgenome.Mmusculus.UCSC.mm10,
        ComplexUpset, plyranges, scales, Matrix, consensusSeekeR,
        heatmaply, viridis
VignetteBuilder: knitr
biocViews: Epigenetics, Genetics, QualityControl, ChIPSeq,
        MultipleComparison, FunctionalGenomics, ATACSeq, DNaseSeq
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: FALSE
RoxygenNote: 7.3.3
git_url: https://git.bioconductor.org/packages/EpiCompare
git_branch: RELEASE_3_22
git_last_commit: c5d211a
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 03:49:48 UTC; biocbuild
Author: Sera Choi [aut] (ORCID: <https://orcid.org/0000-0002-5077-1984>),
  Brian Schilder [aut] (ORCID: <https://orcid.org/0000-0001-5949-2191>),
  Leyla Abbasova [aut],
  Alan Murphy [aut] (ORCID: <https://orcid.org/0000-0002-2487-8753>),
  Nathan Skene [aut] (ORCID: <https://orcid.org/0000-0002-6807-3180>),
  Thomas Roberts [ctb],
  Hiranyamaya Dash [cre] (ORCID: <https://orcid.org/0009-0005-5514-505X>)
Maintainer: Hiranyamaya Dash <hdash.work@gmail.com>
