# Generated by roxygen2: do not edit by hand

export(EpiCompare)
export(bpplapply)
export(check_workers)
export(compute_consensus_peaks)
export(compute_corr)
export(download_button)
export(fragment_info)
export(gather_files)
export(group_files)
export(liftover_grlist)
export(overlap_heatmap)
export(overlap_percent)
export(overlap_stat_plot)
export(overlap_upset_plot)
export(peak_info)
export(plot_ChIPseeker_annotation)
export(plot_chromHMM)
export(plot_corr)
export(plot_enrichment)
export(plot_precision_recall)
export(precision_recall)
export(predict_precision_recall)
export(rebin_peaks)
export(report_command)
export(report_header)
export(tidy_chromosomes)
export(tidy_peakfile)
export(translate_genome)
export(tss_plot)
export(width_boxplot)
export(write_example_peaks)
import(GenomicRanges)
import(ggplot2)
importFrom(AnnotationHub,AnnotationHub)
importFrom(BiocGenerics,"%in%")
importFrom(BiocGenerics,`%in%`)
importFrom(ChIPseeker,annotatePeak)
importFrom(ChIPseeker,enrichPeakOverlap)
importFrom(ChIPseeker,getPromoters)
importFrom(ChIPseeker,getTagMatrix)
importFrom(ChIPseeker,plotAvgProf)
importFrom(ChIPseeker,readPeakFile)
importFrom(GenomeInfoDb,keepSeqlevels)
importFrom(GenomeInfoDb,mapGenomeBuilds)
importFrom(GenomeInfoDb,seqlevelsStyle)
importFrom(GenomeInfoDb,standardChromosomes)
importFrom(GenomicRanges,GRanges)
importFrom(GenomicRanges,GRangesList)
importFrom(GenomicRanges,binnedAverage)
importFrom(GenomicRanges,coverage)
importFrom(GenomicRanges,elementMetadata)
importFrom(GenomicRanges,end)
importFrom(GenomicRanges,makeGRangesFromDataFrame)
importFrom(GenomicRanges,mcols)
importFrom(GenomicRanges,seqinfo)
importFrom(GenomicRanges,seqnames)
importFrom(GenomicRanges,start)
importFrom(GenomicRanges,tileGenome)
importFrom(IRanges,from)
importFrom(IRanges,reduce)
importFrom(IRanges,slice)
importFrom(IRanges,to)
importFrom(Seqinfo,"genome<-")
importFrom(Seqinfo,Seqinfo)
importFrom(Seqinfo,genome)
importFrom(Seqinfo,seqlevels)
importFrom(Seqinfo,seqlevelsInUse)
importFrom(Seqinfo,seqnames)
importFrom(Seqinfo,sortSeqlevels)
importFrom(data.table,":=")
importFrom(data.table,as.data.table)
importFrom(data.table,data.table)
importFrom(data.table,dcast)
importFrom(data.table,fread)
importFrom(data.table,fwrite)
importFrom(data.table,rbindlist)
importFrom(downloadthis,download_file)
importFrom(downloadthis,download_this)
importFrom(genomation,heatTargetAnnotation)
importFrom(genomation,readBed)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(htmltools,save_html)
importFrom(htmltools,tagList)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,show)
importFrom(parallel,detectCores)
importFrom(plotly,as_widget)
importFrom(plotly,ggplotly)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(reshape2,melt)
importFrom(rmarkdown,render)
importFrom(rtracklayer,import)
importFrom(rtracklayer,liftOver)
importFrom(stats,cor)
importFrom(stats,loess)
importFrom(stats,loess.control)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(stringr,str_split)
importFrom(stringr,str_wrap)
importFrom(utils,browseURL)
importFrom(utils,data)
importFrom(utils,packageVersion)
importFrom(utils,tail)
importMethodsFrom(ChIPseeker,plotAnnoBar)
importMethodsFrom(GenomicRanges,width)
importMethodsFrom(IRanges,findOverlaps)
importMethodsFrom(IRanges,subsetByOverlaps)
importMethodsFrom(genomation,annotateWithFeatures)
importMethodsFrom(rtracklayer,liftOver)
