---
title: "Example report"
author: "<h4>Authors: <i>`r auths <- eval(parse(text = gsub('person','c',read.dcf('../DESCRIPTION', fields = 'Authors@R'))));paste(auths[names(auths)=='given'],auths[names(auths)=='family'], collapse = ', ')`</i></h4>" 
date: "<h4>Vignette updated: <i>`r format( Sys.Date(), '%b-%d-%Y')`</i></h4>"
output:
  BiocStyle::html_document:
vignette: >
    %\VignetteIndexEntry{example_report} 
    %\usepackage[utf8]{inputenc}
    %\VignetteEngine{knitr::rmarkdown} 
---
 

### `EpiArchives` is a public archive for interactive HTML reports generated by [`EpiCompare`](https://github.com/neurogenomics/EpiCompare) and the associated code used to create them.

# [Home](https://neurogenomics.github.io/EpiArchives)
## Reports

### [atac_dnase_chip_example](https://neurogenomics.github.io/EpiArchives/reports/atac_dnase_chip_example/EpiCompare.html)
- Analysis of ATAC-seq, DNase-seq and ChIP-seq data from K562 cells. All data comes from [ENCODE](https://www.encodeproject.org/). Only chromosome 1 is analysed in this example.
- [Code to reproduce](https://github.com/neurogenomics/EpiArchives/blob/master/reports/atac_dnase_chip_example/EpiCompare_code.R).

### [atac_dnase_example](https://neurogenomics.github.io/EpiArchives/reports/atac_dnase_example/EpiCompare.html)
- Analysis of ATAC-seq, DNase-seq data from K562 cells. All data comes from [ENCODE](https://www.encodeproject.org/).
- [Code to reproduce](https://github.com/neurogenomics/EpiArchives/blob/master/reports/atac_dnase_example/EpiCompare_code.R).

# Session Information

<details>

```{r Session_Info_vignette}
utils::sessionInfo()
```

</details> 

