% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{CnT_H3K27ac_picard}
\alias{CnT_H3K27ac_picard}
\title{Example Picard duplication metrics file 1}
\format{
An object of class \code{data.frame} with 1 rows and 10 columns.
}
\source{
The code to prepare the .Rda file is:

\code{picard <- read.table("path/to/picard/duplication/output", 
header = TRUE, fill = TRUE)]} \cr
\code{CnT_H3K27ac_picard <- picard[1,]} \cr
\code{usethis::use_data(CnT_H3K27ac_picard, overwrite = TRUE)} \cr
}
\usage{
data("CnT_H3K27ac_picard")
}
\description{
Duplication metrics output of CUT&Tag H3K27ac file 
(sample accession: SRR8581604).
Raw sequences were aligned to hg19 genome and Picard 
was performed by Leyla Abbasova.
The duplication summary output generated by Picard was processed 
to reduce the size of data.
}
\keyword{datasets}
