% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stopper.R
\name{stopper}
\alias{stopper}
\title{Stop messages}
\usage{
stopper(..., v = TRUE)
}
\arguments{
\item{v}{Whether to print messages or not.}
}
\value{
Null
}
\description{
Conditionally print stop messages.
Allows developers to easily control verbosity of functions, 
 and meet Bioconductor requirements that dictate the stop message 
 must first be stored to a variable before passing to \link[base]{stop}.
}
\keyword{internal}
